==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-ukrainian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_YOURNAME"," '");

define("_OK","Ok!");
define("_COMMENT"," ");

define("_CONFIGURE","");
define("_LOGINCREATE","/ ");
define("_THRESHOLD","³  ");
define("_NOCOMMENTS"," ");
define("_NESTED"," ");
define("_FLAT"," ");
define("_THREAD","  ");
define("_OLDEST","  ");
define("_NEWEST","  ");
define("_HIGHEST","  ");
define("_COMMENTSWARNING","     .      .");
define("_SCORE",":");


define("_USERINFO","  ");
define("_READREST"," ...");
define("_REPLY","³   ");
define("_REPLYMAIN"," ");
define("_NOSUBJECT"," ");
define("_NOANONCOMMENTS","    - <a href=\"user.php\"></a>");
define("_PARENT","");
define("_ROOT","");

define("_UCOMMENT","");
define("_ALLOWEDHTML"," HTML-:");
define("_POSTANON","³ ");
define("_EXTRANS","Extrans (html-  )");
define("_HTMLFORMATED","³  HTML-");
define("_PLAINTEXT"," ");
define("_ONN"," ...");
define("_SUBJECT","");
define("_SURVEYCOM","  ");
define("_SURVEYCOMPRE","  ");
define("_NOTRIGHT","      .    .");
define("_DIRECTCOM","  ...");
define("_SENDAMSG","³ ");

define("_PASTSURVEYS"," ");



define("_LVOTES","");
define("_TOTALVOTES"," :");
define("_VOTING"," ");
define("_OTHERPOLLS"," ");
define("_CURRENTSURVEY"," ");
define("_CURRENTPOLLRESULTS","  ");
define("_PREVIEW"," ");


define("_REFRESH","");
define("_SURVEYS","");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-ukrainian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_YOURNAME"," '");

define("_OK","Ok!");
define("_COMMENT"," ");

define("_CONFIGURE","");
define("_LOGINCREATE","/ ");
define("_THRESHOLD","³  ");
define("_NOCOMMENTS"," ");
define("_NESTED"," ");
define("_FLAT"," ");
define("_THREAD","  ");
define("_OLDEST","  ");
define("_NEWEST","  ");
define("_HIGHEST","  ");
define("_COMMENTSWARNING","     .      .");
define("_SCORE",":");


define("_USERINFO","  ");
define("_READREST"," ...");
define("_REPLY","³   ");
define("_REPLYMAIN"," ");
define("_NOSUBJECT"," ");
define("_NOANONCOMMENTS","    - <a href=\"user.php\"></a>");
define("_PARENT","");
define("_ROOT","");

define("_UCOMMENT","");
define("_ALLOWEDHTML"," HTML-:");
define("_POSTANON","³ ");
define("_EXTRANS","Extrans (html-  )");
define("_HTMLFORMATED","³  HTML-");
define("_PLAINTEXT"," ");
define("_ONN"," ...");
define("_SUBJECT","");
define("_SURVEYCOM","  ");
define("_SURVEYCOMPRE","  ");
define("_NOTRIGHT","      .    .");
define("_DIRECTCOM","  ...");
define("_SENDAMSG","³ ");

define("_PASTSURVEYS"," ");



define("_LVOTES","");
define("_TOTALVOTES"," :");
define("_VOTING"," ");
define("_OTHERPOLLS"," ");
define("_CURRENTSURVEY"," ");
define("_CURRENTPOLLRESULTS","  ");
define("_PREVIEW"," ");


define("_REFRESH","");
define("_SURVEYS","");
define("_ATTACHEDTOARTICLE","- Attached to article:");
define("_SURVEYSATTACHED","Surveys Attached to Articles");

?>
